@@ -126,13 +126,13 @@
 #' @seealso \code{\link{network}}
 #' @references Batagelj, Vladimir and Mrvar, Andrej (2011) Pajek Reference
 #' Manual version 2.05
-#' \url{http://vlado.fmf.uni-lj.si/pub/networks/pajek/doc/pajekman.pdf} Section
+#' \url{http://web.archive.org/web/20240906013709/http://vlado.fmf.uni-lj.si/pub/networks/pajek/doc/pajekman.pdf} Section
 #' 5.3 pp 73-79
 #' 
 #' Batageli, Vladimir (2008) "Network Analysis Description of Networks"
-#' \url{http://vlado.fmf.uni-lj.si/pub/networks/doc/ECPR/08/ECPR01.pdf}
+#' \url{http://web.archive.org/web/20240511173536/http://vlado.fmf.uni-lj.si/pub/networks/doc/ECPR/08/ECPR01.pdf}
 #' 
-#' Pajek Datasets \url{http://vlado.fmf.uni-lj.si/pub/networks/data/esna/}
+#' Pajek Datasets \url{http://web.archive.org/web/20240411203537/http://vlado.fmf.uni-lj.si/pub/networks/data/esna}
 #' @keywords datasets
 #' @examples
 #' 
@@ -841,7 +841,7 @@ postProcessProject<-function(
   colnames(vertex) <- c("vertex.numbers","vertex.names","cen1","cen2")[1:ncol(vertex)]
   networks <- vector("list",length=nnetworks)
   if(verbose) print(paste("processing networks:",paste(network.names,collapse=', ')))
-  for(i in seq(along=network.names)){
+  for(i in seq(along.with=network.names)){
     temp <- networksData[[i]]
     isDynamic<-FALSE
     if(!is.null(vertex)){  
@@ -1066,7 +1066,7 @@ read.paj.simplify <- function(x,file,verbose=FALSE)
       "as well as Pajek 'partiton' information.\n",sep=""))
      cat(paste("The collection names are:\n  ",
       paste(cnames,collapse="\n  "),"\n",sep=""))
-     for(i in seq(along=cnames)){
+     for(i in seq(along.with=cnames)){
       thisnet <- x$networks[[i]]
       classthisnet <- class(thisnet)
       if(inherits(thisnet,"network.series") & length(thisnet$networks)==1){
