@@ -6,7 +6,7 @@
 # David Hunter <dhunter@stat.psu.edu> and Mark S. Handcock
 # <handcock@u.washington.edu>.
 #
-# Last Modified 06/06/21
+# Last Modified 06/08/21
 # Licensed under the GNU General Public License version 2 (June, 1991)
 # or greater
 #
@@ -20,6 +20,7 @@
 #   is.discrete
 #   is.discrete.character
 #   is.discrete.numeric
+#   which.matrix.type
 #
 ######################################################################
 
@@ -343,6 +344,7 @@ print.mixingmatrix <- function(x, ...) {
 #' density?
 #' @param discount.bipartite logical; if \code{x} is bipartite, should
 #' \dQuote{forbidden} edges be excluded from the count of potential edges?
+#' @param ... additional arguments to methods
 #' @return The network density.
 #' @section Warning : \code{network.density} relies on network attributes (see
 #' \link{network.indicators}) to determine the properties of the underlying
@@ -353,7 +355,7 @@ print.mixingmatrix <- function(x, ...) {
 #' @seealso \code{\link{network.edgecount}}, \code{\link{network.size}}
 #' @references Butts, C. T.  (2008).  \dQuote{network: a Package for Managing
 #' Relational Data in R.} \emph{Journal of Statistical Software}, 24(2).
-#' \url{https://www.jstatsoft.org/v24/i02/}
+#' \doi{10.18637/jss.v024.i02}
 #' 
 #' Wasserman, S. and Faust, K.  (1994).  \emph{Social Network Analysis: Methods
 #' and Applications.} Cambridge: Cambridge University Press.
@@ -369,7 +371,11 @@ print.mixingmatrix <- function(x, ...) {
 #' 
 #' @rdname network.density
 #' @export network.density
-network.density<-function(x,na.omit=TRUE,discount.bipartite=FALSE){
+network.density <- function(x, na.omit=TRUE, discount.bipartite=FALSE, ...) UseMethod("network.density")
+
+#' @rdname network.density
+#' @export
+network.density.network <- function(x, na.omit=TRUE, discount.bipartite=FALSE, ...){
   if(!is.network(x))
     stop("network.density requires a network object.")
   if(network.size(x)==0){
@@ -412,6 +418,7 @@ network.density<-function(x,na.omit=TRUE,discount.bipartite=FALSE){
 #' @aliases is.isolate
 #' @param net a \code{\link{network}} object to be queried
 #' @param v integer vector of vertex ids to check
+#' @param ... additional arguments to methods
 #' @return returns a logical vector with the same length as v, with TRUE if the
 #' vertex is involved in any edges, FALSE if it is an isolate.
 #' @author skyebend
@@ -424,7 +431,11 @@ network.density<-function(x,na.omit=TRUE,discount.bipartite=FALSE){
 #' 
 #' @rdname has.edges
 #' @export has.edges
-has.edges<-function(net,v=seq_len(network.size(net))){
+has.edges <- function(net, v=seq_len(network.size(net)), ...) UseMethod("has.edges")
+
+#' @rdname has.edges
+#' @export
+has.edges.network <- function(net, v=seq_len(network.size(net)), ...){
   if(network.size(net)==0){
     return(logical(0))
   }
@@ -467,7 +478,6 @@ is.color<-function(x){
 #' @param x an object to be designated either discrete or continuous, or a
 #' network.
 #' @param y a network or something coercible to one.
-#' @param \dots further arguments passed to or used by methods.
 #' 
 #' @seealso network
 #' 
@@ -518,7 +528,7 @@ is.discrete<-function(x){
 #' @seealso \code{\link{as.matrix.network}}, \code{\link{as.network.matrix}}
 #' @references Butts, C. T.  (2008).  \dQuote{network: a Package for Managing
 #' Relational Data in R.} \emph{Journal of Statistical Software}, 24(2).
-#' \url{https://www.jstatsoft.org/v24/i02/}
+#' \doi{10.18637/jss.v024.i02}
 #' @keywords graphs
 #' @examples
 #' 
@@ -551,6 +561,8 @@ which.matrix.type<-function(x)
             out<-NA
         else if (diff(dim(x))==0)  
             out<-"adjacency"
+        else if (NROW(x)==0)  #For a 0-row matrix, an empty edgelist is the best bet...
+            out<-"edgelist"
         else if (max(abs(x),na.rm=TRUE)==1 && max(abs(x-as.integer(x)),na.rm=TRUE)==0)
             out<-"bipartite"
         else if (max(abs(x-as.integer(x))[,1:2],na.rm=TRUE)==0 && min(x[,1:2],na.rm=TRUE)>0)
@@ -568,23 +580,3 @@ which.matrix.type<-function(x)
     }
     out
 }
-
-
-# This is a temporary transplant from statnet.common, copied here to ease transition on CRAN.
-#' @importFrom statnet.common EVL
-simplify_simple <- function(x, toNA = c("null","empty","keep"), empty = c("keep", "unlist"), ...){
-  if(isFALSE(toNA)) toNA <- "keep"
-  toNA <- match.arg(toNA)
-  empty <- match.arg(empty)
-
-  if(is.atomic(x)) return(x)
-
-  x <- switch(toNA,
-              keep = x,
-              null = lapply(x, NVL, NA),
-              empty = lapply(x, EVL, NA))
-
-  if(length(x)==0) switch(empty, keep=x, unlist=unlist(x, recursive=FALSE, ...))
-  else if(all(lengths(x)==1L) && all(vapply(x, is.atomic, logical(1)))) unlist(x, recursive=FALSE, ...)
-  else x
-}
